! Stomate: phenology, allocation, etc.
!
! authors: A. Botta, P. Friedlingstein, C. Morphopoulos, N. Viovy, et al.
!
! bits and pieces put together by G. Krinner
!
! version 0.0: August 1998
!
! $Header: /home/ssipsl/CVSREP/ORCHIDEE/src_stomate/stomate_lpj.f90,v 1.6 2002/12/13 16:06:44 ssipsl Exp $
!
MODULE stomate_lpj

  ! modules used:

  USE ioipsl
  USE stomate_constants
  USE lpj_constraints
  USE lpj_pftinout
  USE lpj_kill
  USE lpj_crown
  USE lpj_fire
  USE lpj_gap
  USE lpj_light
  USE lpj_establish
  USE lpj_cover
  USE stomate_prescribe
  USE stomate_phenology
  USE stomate_alloc
  USE stomate_npp
  USE stomate_turnover
  USE stomate_litter
  USE stomate_soilcarbon
  USE stomate_vmax
  USE stomate_assimtemp

  IMPLICIT NONE

  ! private & public routines

  PRIVATE
  PUBLIC StomateLpj,StomateLpj_clear

CONTAINS
 
 SUBROUTINE StomateLpj_clear

   CALL prescribe_clear
   CALL phenology_clear
   CALL npp_calc_clear
   CALL turn_clear
   CALL soilcarbon_clear
   CALL constraints_clear
   CALL establish_clear
   CALL fire_clear
   CALL gap_clear
   CALL light_clear
   CALL pftinout_clear
   CALL alloc_clear
 END SUBROUTINE StomateLpj_clear

  SUBROUTINE StomateLpj (npts, dt_days, &
                 neighbours, resolution, space_nat, &
                 clay, herbivores, &
                 tsurf_daily, tsoil_daily, t2m_daily, t2m_min_daily, &
                 litterhum_daily, soilhum_daily, &
                 maxmoiavail_lastyear, minmoiavail_lastyear, &
                 gdd0_lastyear, precip_lastyear, &
                 moiavail_month, moiavail_week, tlong_ref, t2m_month, t2m_week, &
                 tsoil_month, soilhum_month, &
                 gdd_m5_dormance, gdd_midwinter, ncd_dormance, ngd_minus5, &
                 turnover_longterm, gpp_daily, time_lowgpp, &
                 time_hum_min, maxfpc_lastyear, &
                 PFTpresent, age, fireindex, firelitter, &
                 leaf_age, leaf_frac, biomass, ind, adapted, regenerate, &
                 senescence, when_growthinit, &
                 litterpart, litter, dead_leaves, carbon, black_carbon, lignin_struc, &
                 veget_max, veget, npp_longterm, lm_lastyearmax, veget_lastlight, &
                 everywhere, need_adjacent, RIP_time, &
                 lai, npp_daily, turnover_daily, turnover_time,&
                 control_moist, control_temp, soilcarbon_input, &
                 co2_to_bm, co2_fire, resp_hetero, resp_maint, resp_growth, &
                 height, deadleaf_cover, vcmax, vjmax, t_photo_min, t_photo_opt, t_photo_max)

    !
    ! 0 declarations
    !

    ! 0.1 input

    ! Domain size
    INTEGER, INTENT(in)                                           :: npts
    ! time step of Stomate in days
    REAL(stnd), INTENT(in)                                        :: dt_days
    ! indices of the 8 neighbours of each grid point (1=N, 2=NE, 3=E, 4=SE, 5=S, 6=SW, 7=W, 8=NW)
    INTEGER(long), DIMENSION(npts,8), INTENT(in)                  :: neighbours
    ! resolution at each grid point in m (1=E-W, 2=N-S)
    REAL(stnd), DIMENSION(npts,2), INTENT(in)                     :: resolution
    ! total natural space (fraction of total space)
    REAL(stnd), DIMENSION(npts), INTENT(in)                       :: space_nat
    ! clay fraction
    REAL(stnd), DIMENSION(npts), INTENT(in)                       :: clay
    ! time constant of probability of a leaf to be eaten by a herbivore (days)
    REAL(stnd), DIMENSION(npts,npft), INTENT(in)                  :: herbivores
    ! daily surface temperatures (K)
    REAL(stnd), DIMENSION(npts), INTENT(in)                       :: tsurf_daily
    ! daily soil temperatures (K)
    REAL(stnd), DIMENSION(npts,nbdl), INTENT(in)                  :: tsoil_daily
    ! daily 2 meter temperatures (K)
    REAL(stnd), DIMENSION(npts), INTENT(in)                       :: t2m_daily
    ! daily minimum 2 meter temperatures (K)
    REAL(stnd), DIMENSION(npts), INTENT(in)                       :: t2m_min_daily
    ! daily litter humidity
    REAL(stnd), DIMENSION(npts), INTENT(in)                       :: litterhum_daily
    ! daily soil humidity
    REAL(stnd), DIMENSION(npts,nbdl), INTENT(in)                  :: soilhum_daily
    ! last year's maximum moisture availability
    REAL(stnd), DIMENSION(npts,npft), INTENT(in)                  :: maxmoiavail_lastyear
    ! last year's minimum moisture availability
    REAL(stnd), DIMENSION(npts,npft), INTENT(in)                  :: minmoiavail_lastyear
    ! last year's GDD0
    REAL(stnd), DIMENSION(npts), INTENT(in)                       :: gdd0_lastyear
    ! lastyear's precipitation (mm/year)
    REAL(stnd), DIMENSION(npts), INTENT(in)                       :: precip_lastyear
    ! "monthly" moisture availability
    REAL(stnd), DIMENSION(npts,npft), INTENT(in)                  :: moiavail_month
    ! "weekly" moisture availability
    REAL(stnd), DIMENSION(npts,npft), INTENT(in)                  :: moiavail_week
    ! "long term" 2 meter reference temperatures (K)
    REAL(stnd), DIMENSION(npts), INTENT(in)                       :: tlong_ref
    ! "monthly" 2-meter temperatures (K)
    REAL(stnd), DIMENSION(npts), INTENT(in)                       :: t2m_month
    ! "weekly" 2-meter temperatures (K)
    REAL(stnd), DIMENSION(npts), INTENT(in)                       :: t2m_week
    ! "monthly" soil temperatures (K)
    REAL(stnd), DIMENSION(npts,nbdl), INTENT(in)                  :: tsoil_month
    ! "monthly" soil humidity
    REAL(stnd), DIMENSION(npts,nbdl), INTENT(in)                  :: soilhum_month
    ! growing degree days, threshold -5 deg C (for phenology)
    REAL(stnd), DIMENSION(npts,npft), INTENT(in)                  :: gdd_m5_dormance
    ! growing degree days, since midwinter (for phenology)
    REAL(stnd), DIMENSION(npts,npft), INTENT(in)                  :: gdd_midwinter
    ! number of chilling days, since leaves were lost (for phenology)
    REAL(stnd), DIMENSION(npts,npft), INTENT(in)                  :: ncd_dormance
    ! number of growing days, threshold -5 deg C (for phenology)
    REAL(stnd), DIMENSION(npts,npft), INTENT(in)                  :: ngd_minus5
    ! "long term" turnover rate (gC/(m**2 of nat/agri ground)/year)
    REAL(stnd), DIMENSION(npts,npft,nparts), INTENT(in)           :: turnover_longterm
    ! daily gross primary productivity (gC/(m**2 of nat/agri ground)/day)
    REAL(stnd), DIMENSION(npts,npft), INTENT(in)                  :: gpp_daily
    ! duration of dormance (d)
    REAL(stnd), DIMENSION(npts,npft), INTENT(in)                  :: time_lowgpp
    ! time elapsed since strongest moisture availability (d)
    REAL(stnd), DIMENSION(npts,npft), INTENT(in)                  :: time_hum_min
    ! last year's maximum fpc for each natural PFT, on *natural* ground
    REAL(stnd), DIMENSION(npts,npft), INTENT(in)                  :: maxfpc_lastyear

    ! 0.2 modified fields

    ! PFT exists
    LOGICAL, DIMENSION(npts,npft), INTENT(inout)                  :: PFTpresent
    ! age (years)
    REAL(stnd), DIMENSION(npts,npft), INTENT(inout)               :: age
    ! Probability of fire
    REAL(stnd), DIMENSION(npts,nvegtypes), INTENT(inout)          :: fireindex
    ! Longer term litter above the ground, gC/m**2 of nat/agri ground
    REAL(stnd), DIMENSION(npts,nvegtypes), INTENT(inout)          :: firelitter
    ! leaf age (days)
    REAL(stnd), DIMENSION(npts,npft,nleafages), INTENT(inout)     :: leaf_age
    ! fraction of leaves in leaf age class
    REAL(stnd), DIMENSION(npts,npft,nleafages), INTENT(inout)     :: leaf_frac
    ! biomass (gC/(m**2 of nat/agri ground))
    REAL(stnd), DIMENSION(npts,npft,nparts), INTENT(inout)        :: biomass
    ! density of individuals (1/(m**2 of nat/agri ground))
    REAL(stnd), DIMENSION(npts,npft), INTENT(inout)               :: ind
    ! Winter too cold? between 0 and 1
    REAL(stnd), DIMENSION(npts,npft), INTENT(inout)               :: adapted
    ! Winter sufficiently cold? between 0 and 1
    REAL(stnd), DIMENSION(npts,npft), INTENT(inout)               :: regenerate
    ! is the plant senescent? (only for deciduous trees - carbohydrate reserve)
    LOGICAL, DIMENSION(npts,npft), INTENT(inout)                  :: senescence
    ! how many days ago was the beginning of the growing season
    REAL(stnd), DIMENSION(npts,npft), INTENT(inout)               :: when_growthinit
    ! fraction of litter above the ground belonging to different PFTs
    REAL(stnd), DIMENSION(npts,npft,nlitt), INTENT(inout)         :: litterpart
    ! metabolic and structural litter, natural and agricultural,
    !   above and below ground (gC/(m**2 of nat/agri ground))
    REAL(stnd), DIMENSION(npts,nlitt,nvegtypes,nlevs), INTENT(inout)  :: litter
    ! dead leaves on ground, per PFT, metabolic and structural, 
    !   in gC/(m**2 of nat/agri ground)
    REAL(stnd), DIMENSION(npts,npft,nlitt), INTENT(inout)         :: dead_leaves
    ! carbon pool: active, slow, or passive, natural and agricultural
    !   (gC/(m**2 of nat/agri ground))
    REAL(stnd), DIMENSION(npts,ncarb,nvegtypes), INTENT(inout)    :: carbon
    ! black carbon on the ground (gC/(m**2 of total ground))
    REAL(stnd), DIMENSION(npts), INTENT(inout)                    :: black_carbon
    ! ratio Lignine/Carbon in structural litter, above and below ground,
    !   natural and agricultural (gC/(m**2 of nat/agri ground))
    REAL(stnd), DIMENSION(npts,nvegtypes,nlevs), INTENT(inout)    :: lignin_struc
    ! "maximal" coverage fraction of a PFT (LAI -> infinity) on nat/agri ground
    REAL(stnd), DIMENSION(npts,npft), INTENT(inout)               :: veget_max
    ! fractional coverage on natural/agricultural ground, taking into
    !   account LAI (=grid-scale fpc)
    REAL(stnd), DIMENSION(npts,npft), INTENT(inout)               :: veget
    ! "long term" net primary productivity (gC/(m**2 of nat/agri ground)/year)
    REAL(stnd), DIMENSION(npts,npft), INTENT(inout)               :: npp_longterm
    ! last year's maximum leaf mass, for each PFT (gC/(m**2 of nat/agri ground))
    REAL(stnd), DIMENSION(npts,npft), INTENT(inout)               :: lm_lastyearmax
    ! vegetation fractions (on natural/agri ground) after last light competition
    REAL(stnd), DIMENSION(npts,npft), INTENT(inout)               :: veget_lastlight
    ! is the PFT everywhere in the grid box or very localized (after its introduction)
    REAL(stnd), DIMENSION(npts,npft), INTENT(inout)               :: everywhere
    ! in order for this PFT to be introduced, does it have to be present in an
    !   adjacent grid box?
    LOGICAL, DIMENSION(npts,npft), INTENT(inout)                  :: need_adjacent
    ! How much time ago was the PFT eliminated for the last time (y)
    REAL(stnd), DIMENSION(npts,npft), INTENT(inout)               :: RIP_time
    ! Turnover_time of leaves for grasses (d)
    REAL(stnd), DIMENSION(npts,npft), INTENT(inout)          :: turnover_time
 
    ! 0.3 output

    ! leaf area index OF AN INDIVIDUAL PLANT
    REAL(stnd), DIMENSION(npts,npft), INTENT(inout)                 :: lai
    ! net primary productivity (gC/day/(m**2 of nat/agri ground))
    REAL(stnd), DIMENSION(npts,npft), INTENT(out)                 :: npp_daily
    ! Turnover rates (gC/(m**2 of nat/agri ground)/day)
    REAL(stnd), DIMENSION(npts,npft,nparts), INTENT(out)          :: turnover_daily
    ! moisture control of heterotrophic respiration
    REAL(stnd), DIMENSION(npts,nlevs), INTENT(out)                :: control_moist
    ! temperature control of heterotrophic respiration, above and below
    REAL(stnd), DIMENSION(npts,nlevs), INTENT(out)                :: control_temp
    ! quantity of carbon going into carbon pools from litter decomposition
    !   (gC/(m**2 of nat/agri ground)/day)
    REAL(stnd), DIMENSION(npts,ncarb,nvegtypes), INTENT(out)      :: soilcarbon_input
    ! co2 taken up (gC/(m**2 of total ground)/day)
    REAL(stnd), DIMENSION(npts), INTENT(out)                      :: co2_to_bm
    ! carbon emitted into the atmosphere by fire (living and dead biomass)
    ! (in gC/m**2 of total ground/day)
    REAL(stnd), DIMENSION(npts), INTENT(out)                      :: co2_fire
    ! heterotrophic respiration (gC/day/m**2 of total ground)
    REAL(stnd), DIMENSION(npts,nvegtypes), INTENT(out)            :: resp_hetero
    ! maintenance respiration (gC/day/(m**2 of total ground))
    REAL(stnd), DIMENSION(npts,npft), INTENT(out)                 :: resp_maint
    ! growth respiration (gC/day/(m**2 of total ground))
    REAL(stnd), DIMENSION(npts,npft), INTENT(out)                 :: resp_growth
    ! height of vegetation (m)
    REAL(stnd), DIMENSION(npts,npft), INTENT(inout)                 :: height
    ! fraction of soil covered by dead leaves
    REAL(stnd), DIMENSION(npts), INTENT(out)                      :: deadleaf_cover
    ! Maximum rate of carboxylation
    REAL(stnd), DIMENSION(npts,npft), INTENT(out)                 :: vcmax
    ! Maximum rate of RUbp regeneration
    REAL(stnd), DIMENSION(npts,npft), INTENT(out)                 :: vjmax
    ! Minimum temperature for photosynthesis (deg C)
    REAL(stnd), DIMENSION(npts,npft), INTENT(out)                 :: t_photo_min
    ! Optimum temperature for photosynthesis (deg C)
    REAL(stnd), DIMENSION(npts,npft), INTENT(out)                 :: t_photo_opt
    ! Maximum temperature for photosynthesis (deg C)
    REAL(stnd), DIMENSION(npts,npft), INTENT(out)                 :: t_photo_max

    ! 0.4 local

    ! root depth. This will, one day, be a prognostic variable. It will be calculated by
    ! STOMATE (save in restart file & give to hydrology module!), probably somewhere
    ! in the allocation routine. For the moment, it is prescribed.
    REAL(stnd), DIMENSION(npts,npft)                              :: rprof
    ! conversion of biomass to litter (gC/(m**2 of nat/agri ground)) / day
    REAL(stnd), DIMENSION(npts,npft,nparts)                       :: bm_to_litter
     ! total conversion of biomass to litter (gC/(m**2)) / day
    REAL(stnd), DIMENSION(npts,npft)                                   :: tot_bm_to_litter
    ! total living biomass (gC/(m**2)) 
    REAL(stnd), DIMENSION(npts,npft)                                   :: tot_live_biomass
    ! total turnover rate (gC/(m**2)) / day
    REAL(stnd), DIMENSION(npts,npft)                                   :: tot_turnover
    ! total soil and litter carbon (gC/(m**2))
    REAL(stnd), DIMENSION(npts)                                   :: tot_soil_carb
   ! crown area of individuals (m**2)
    REAL(stnd), DIMENSION(npts,npft)                              :: cn_ind
    ! fraction that goes into plant part
    REAL(stnd), DIMENSION(npts,npft,nparts)                       :: f_alloc
    ! space availability for trees
    REAL(stnd), DIMENSION(npts)                                   :: avail_tree
    ! space availability for grasses
    REAL(stnd), DIMENSION(npts)                                   :: avail_grass
    ! litter heterotrophic respiration (gC/day/m**2 of total ground)
    REAL(stnd), DIMENSION(npts,nvegtypes)                         :: resp_hetero_litter
    ! soil heterotrophic respiration (gC/day/m**2 of total ground)
    REAL(stnd), DIMENSION(npts,nvegtypes)                         :: resp_hetero_soil

    ! =========================================================================

    IF (bavard.GE.3) WRITE(numout,*) 'Entering stomate_lpj'

    !
    ! 1 Initializations
    !

    !
    ! 1.1 set outputs to zero
    !

    co2_to_bm(:) = 0.0
    co2_fire(:) = 0.0
     npp_daily(:,:) = 0.0
    turnover_daily(:,:,:) = 0.0
    resp_hetero(:,:) = 0.0
    resp_maint(:,:) = 0.0
    resp_growth(:,:) = 0.0

    !
    ! 1.2  initialize some variables
    !

    bm_to_litter(:,:,:) = 0.0
    cn_ind(:,:) = 0.0

    !
    ! 1.3 Prescribe some vegetation characteristics if the vegetation is not dynamic and
    !       for agricultural PFTs.
    !     IF the DGVM is not activated, the density of individuals and their crown
    !     areas don't matter, but they should be defined for the case we switch on
    !     the DGVM afterwards.
    !     At first call, if the DGVM is not activated, impose a minimum biomass for 
    !       prescribed PFTs and declare them present.
    !

    CALL prescribe (npts, &
                    space_nat, &
                    veget_max, PFTpresent, everywhere, when_growthinit, &
                    biomass, leaf_frac, ind, cn_ind)

    !
    ! 2 climatic constraints for PFT presence and regenerativeness
    !   call this even when DGVM is not activated so that "adapted" and "regenerate"
    !   are kept up to date for the moment when the DGVM is activated.
    !

    CALL constraints (npts, dt_days, &
                      t2m_month, t2m_min_daily, when_growthinit, &
                      adapted, regenerate)

    !
    ! 3 PFTs in and out, based on climate criteria
    !

    IF ( control%ok_dgvm ) THEN

      !
      ! 3.1 do introduction/elimination
      !

      CALL pftinout (npts, dt_days, adapted, regenerate, &
               neighbours, space_nat, veget, veget_max, &
               biomass, ind, age, leaf_frac, npp_longterm, lm_lastyearmax, senescence, &
               PFTpresent, everywhere, when_growthinit, need_adjacent, RIP_time, &
               co2_to_bm, &
               avail_tree, avail_grass)

      !
      ! 3.2 reset attributes for eliminated PFTs.
      !     This also kills PFTs that had 0 leafmass during the last year. The message
      !     "... after pftinout" is misleading in this case.
      !

      CALL kill (npts, 'pftinout  ', lm_lastyearmax, &
                 ind, PFTpresent, cn_ind, biomass, senescence, RIP_time, &
                 lai, age, leaf_age, leaf_frac, &
                 when_growthinit, everywhere, veget, veget_max, bm_to_litter)

      !
      ! 3.3 calculate new crown area and maximum vegetation cover
      !

      CALL crown (npts, PFTpresent, &
                  ind, biomass, &
                  veget_max, cn_ind, height)

    ENDIF

    !
    ! 4 phenology
    !

    CALL phenology (npts, dt_days, PFTpresent, &
                    veget_max, space_nat, &
                    tlong_ref, t2m_month, t2m_week, gpp_daily, &
                    maxmoiavail_lastyear, minmoiavail_lastyear, &
                    moiavail_month, moiavail_week, &
                    gdd_m5_dormance, gdd_midwinter, ncd_dormance, ngd_minus5, &
                    senescence, time_lowgpp, time_hum_min, &
                    biomass, leaf_frac, leaf_age, &
                    when_growthinit, co2_to_bm, lai)

    !
    ! 5 allocation
    !

    CALL alloc (npts, dt_days, &
                lai, veget_max, senescence, when_growthinit, &
                moiavail_week, tsoil_month, soilhum_month, &
                biomass, leaf_age, leaf_frac, rprof, f_alloc)

    !
    ! 6 maintenance and growth respiration. NPP
    !

    CALL npp_calc (npts, dt_days, space_nat, &
                   PFTpresent, &
                   tlong_ref, t2m_daily, tsoil_daily, lai, rprof, &
                   gpp_daily, f_alloc, &
                   biomass, leaf_age, leaf_frac, age, &
                   resp_maint, resp_growth, npp_daily)

    IF ( control%ok_dgvm ) THEN

      ! new provisional crown area and maximum vegetation cover after growth

      CALL crown (npts, PFTpresent, &
                  ind, biomass, &
                  veget_max, cn_ind, height)

    ENDIF

    !
    ! 7 fire.
    !

    CALL fire (npts, dt_days, space_nat, litterpart, &
               litterhum_daily, t2m_daily, lignin_struc, &
               fireindex, firelitter, biomass, ind, &
               litter, dead_leaves, bm_to_litter, black_carbon, &
               co2_fire)

    IF ( control%ok_dgvm ) THEN

      ! reset attributes for eliminated PFTs

      CALL kill (npts, 'fire      ', lm_lastyearmax, &
                 ind, PFTpresent, cn_ind, biomass, senescence, RIP_time, &
                 lai, age, leaf_age, leaf_frac, &
                 when_growthinit, everywhere, veget, veget_max, bm_to_litter)

    ENDIF

    !
    ! 8 tree mortality. Does not depend on age, therefore does not change crown area.
    !

    CALL gap (npts, dt_days, &
              npp_longterm, turnover_longterm, lm_lastyearmax, &
              PFTpresent, biomass, ind, bm_to_litter)

    IF ( control%ok_dgvm ) THEN

      ! reset attributes for eliminated PFTs

      CALL kill (npts, 'gap       ', lm_lastyearmax, &
                 ind, PFTpresent, cn_ind, biomass, senescence, RIP_time, &
                 lai, age, leaf_age, leaf_frac, &
                 when_growthinit, everywhere, veget, veget_max, bm_to_litter)

    ENDIF

    !
    ! 9 calculate vcmax, vjmax and photosynthesis temperatures
    !

    CALL vmax (npts, dt_days, &
               leaf_age, leaf_frac, &
               vcmax, vjmax)

    CALL assim_temp (npts, tlong_ref, t2m_month, &
                     t_photo_min, t_photo_opt, t_photo_max)

    !
    ! 10 leaf senescence and other turnover processes. New lai
    !

    CALL turn (npts, dt_days, PFTpresent, &
               herbivores, &
               maxmoiavail_lastyear, minmoiavail_lastyear, &
               moiavail_week,  moiavail_month,tlong_ref, t2m_month, t2m_week, veget_max, &
               leaf_age, leaf_frac, age, lai, biomass, &
               turnover_daily, senescence,turnover_time)

    !
    ! 11 light competition
    !

    IF ( control%ok_dgvm ) THEN

      !
      ! 11.1 do light competition
      !

      CALL light (npts, dt_days, &
                  PFTpresent, cn_ind, lai, maxfpc_lastyear, &
                  ind, biomass, veget_lastlight, bm_to_litter)

      !
      ! 11.2 reset attributes for eliminated PFTs
      !

      CALL kill (npts, 'light     ', lm_lastyearmax, &
                 ind, PFTpresent, cn_ind, biomass, senescence, RIP_time, &
                 lai, age, leaf_age, leaf_frac, &
                 when_growthinit, everywhere, veget, veget_max, bm_to_litter)

    ENDIF

    !
    ! 12 establishment of saplings
    !

    IF ( control%ok_dgvm ) THEN

      !
      ! 12.1 do establishment
      !

      CALL establish (npts, dt_days, PFTpresent, regenerate, &
                      neighbours, resolution, space_nat, need_adjacent, herbivores, &
                      precip_lastyear, gdd0_lastyear, lm_lastyearmax, &
                      cn_ind, lai, avail_tree, avail_grass, &
                      leaf_age, leaf_frac, &
                      ind, biomass, age, everywhere, co2_to_bm)

      !
      ! 12.2 calculate new crown area (and maximum vegetation cover)
      !

      CALL crown (npts, PFTpresent, &
                  ind, biomass, &
                  veget_max, cn_ind, height)

    ENDIF

    !
    ! 13 calculate final LAI and vegetation cover.
    !

    CALL cover (npts, cn_ind, ind, biomass, &
                veget_max, veget, lai)

    !
    ! 14 the whole litter stuff:
    !    litter update, lignin content, PFT parts, litter decay, 
    !    litter heterotrophic respiration, dead leaf soil cover.
    !    No vertical discretisation in the soil for litter decay.
    !

    CALL littercalc (npts, dt_days, space_nat, &
                     turnover_daily, bm_to_litter, &
                     tsurf_daily, tsoil_daily, soilhum_daily, litterhum_daily, &
                     litterpart, litter, dead_leaves, lignin_struc, &
                     deadleaf_cover, resp_hetero_litter, &
                     soilcarbon_input, control_temp, control_moist)

    !
    ! 15 soil carbon dynamics: heterotrophic respiration from the soil.
    !    For the moment, no vertical discretisation.
    !    We might later introduce a vertical discretisation. However, in that
    !    case, we would have to treat the vertical exchanges of carbon between the 
    !    different levels.
    !

    CALL soilcarbon (npts, dt_days, clay, space_nat, &
                     soilcarbon_input, control_temp, control_moist, &
                     carbon, &
                     resp_hetero_soil)

    !
    ! 16 total heterotrophic respiration
    !

    resp_hetero = resp_hetero_litter + resp_hetero_soil
    tot_soil_carb = litter(:,istructural,inat,iabove) + litter(:,istructural,iagri,iabove) + &
         &          litter(:,imetabolic,inat,iabove) + litter(:,imetabolic,iagri,iabove) + &
         &          litter(:,istructural,inat,ibelow) +  litter(:,istructural,iagri,ibelow)+ &
         &          litter(:,imetabolic,inat,ibelow) + litter(:,imetabolic,iagri,ibelow) + &
         &          deadleaf_cover+ carbon(:,iactive,inat) + carbon(:,iactive,iagri) + &
         &          carbon(:,islow,inat)+ carbon(:,islow,iagri) + carbon(:,ipassive,inat) + &
         &          carbon(:,ipassive,iagri)

    tot_live_biomass = biomass(:,:,ileaf) + biomass(:,:,isapabove) + biomass(:,:,isapbelow) +&
         &             biomass(:,:,iheartabove) + biomass(:,:,iheartbelow) + &
         &             biomass(:,:,iroot)+ biomass(:,:,ifruit)+ biomass(:,:,icarbres)

    tot_turnover = turnover_daily(:,:,ileaf) + turnover_daily(:,:,isapabove) + &
         &         turnover_daily(:,:,isapbelow) + turnover_daily(:,:,iheartabove) + &
         &         turnover_daily(:,:,iheartbelow) + turnover_daily(:,:,iroot) + &
         &         turnover_daily(:,:,ileaf) + turnover_daily(:,:,icarbres)

    tot_bm_to_litter = bm_to_litter(:,:,ileaf) + bm_to_litter(:,:,isapabove) +&
         &             bm_to_litter(:,:,isapbelow) + bm_to_litter(:,:,iheartbelow) +&
         &             bm_to_litter(:,:,iheartabove) + bm_to_litter(:,:,iroot) + &
         &             bm_to_litter(:,:,ifruit) + bm_to_litter(:,:,icarbres)

    !
    ! 17 history
    !

    ! 2d

    CALL histwrite (hist_id_stomate, 'RESOLUTION_X', itime, &
                    resolution(:,1), npts, hori_index)
    CALL histwrite (hist_id_stomate, 'RESOLUTION_Y', itime, &
                    resolution(:,2), npts, hori_index)
    CALL histwrite (hist_id_stomate, 'SPACE_NAT', itime, &
                    space_nat(:), npts, hori_index)
!    CALL histwrite (hist_id_stomate, 'TOTAL_SOIL_CARB', itime, &
!                    tot_soil_carb, npts, hori_index)
    CALL histwrite (hist_id_stomate, 'LITTER_STR_AB_NAT', itime, &
                    litter(:,istructural,inat,iabove), npts, hori_index)
    CALL histwrite (hist_id_stomate, 'LITTER_STR_AB_AGRI', itime, &
                    litter(:,istructural,iagri,iabove), npts, hori_index)
    CALL histwrite (hist_id_stomate, 'LITTER_MET_AB_NAT', itime, &
                    litter(:,imetabolic,inat,iabove), npts, hori_index)
    CALL histwrite (hist_id_stomate, 'LITTER_MET_AB_AGRI', itime, &
                    litter(:,imetabolic,iagri,iabove), npts, hori_index)
    CALL histwrite (hist_id_stomate, 'LITTER_STR_BE_NAT', itime, &
                    litter(:,istructural,inat,ibelow), npts, hori_index)
    CALL histwrite (hist_id_stomate, 'LITTER_STR_BE_AGRI', itime, &
                    litter(:,istructural,iagri,ibelow), npts, hori_index)
    CALL histwrite (hist_id_stomate, 'LITTER_MET_BE_NAT', itime, &
                    litter(:,imetabolic,inat,ibelow), npts, hori_index)
    CALL histwrite (hist_id_stomate, 'LITTER_MET_BE_AGRI', itime, &
                    litter(:,imetabolic,iagri,ibelow), npts, hori_index)
    CALL histwrite (hist_id_stomate, 'DEADLEAF_COVER', itime, &
                    deadleaf_cover, npts, hori_index)
    CALL histwrite (hist_id_stomate, 'CARBON_ACTIVE_NAT', itime, &
                    carbon(:,iactive,inat), npts, hori_index)
    CALL histwrite (hist_id_stomate, 'CARBON_ACTIVE_AGRI', itime, &
                    carbon(:,iactive,iagri), npts, hori_index)
    CALL histwrite (hist_id_stomate, 'CARBON_SLOW_NAT', itime, &
                    carbon(:,islow,inat), npts, hori_index)
    CALL histwrite (hist_id_stomate, 'CARBON_SLOW_AGRI', itime, &
                    carbon(:,islow,iagri), npts, hori_index)
    CALL histwrite (hist_id_stomate, 'CARBON_PASSIVE_NAT', itime, &
                    carbon(:,ipassive,inat), npts, hori_index)
    CALL histwrite (hist_id_stomate, 'CARBON_PASSIVE_AGRI', itime, &
                    carbon(:,ipassive,iagri), npts, hori_index)
    CALL histwrite (hist_id_stomate, 'T2M_MONTH', itime, &
                    t2m_month, npts, hori_index)
    CALL histwrite (hist_id_stomate, 'T2M_WEEK', itime, &
                    t2m_week, npts, hori_index)
    CALL histwrite (hist_id_stomate, 'HET_RESP_NAT', itime, &
                    resp_hetero(:,inat), npts, hori_index)
    CALL histwrite (hist_id_stomate, 'HET_RESP_AGRI', itime, &
                    resp_hetero(:,iagri), npts, hori_index)
    CALL histwrite (hist_id_stomate, 'BLACK_CARBON', itime, &
                    black_carbon, npts, hori_index)
    CALL histwrite (hist_id_stomate, 'FIREINDEX_NAT', itime, &
                    fireindex(:,inat), npts, hori_index)
    CALL histwrite (hist_id_stomate, 'LITTERHUM', itime, &
                    litterhum_daily, npts, hori_index)
    CALL histwrite (hist_id_stomate, 'CO2_FIRE', itime, &
                    co2_fire, npts, hori_index)
   CALL histwrite (hist_id_stomate, 'CO2_TAKEN', itime, &
                    co2_to_bm, npts, hori_index)

    ! 3d

    CALL histwrite (hist_id_stomate, 'LAI', itime, &
                    lai, npts*npft, horipft_index)
    CALL histwrite (hist_id_stomate, 'VEGET', itime, &
                    veget, npts*npft, horipft_index)
    CALL histwrite (hist_id_stomate, 'VEGET_MAX', itime, &
                    veget_max, npts*npft, horipft_index)
    CALL histwrite (hist_id_stomate, 'NPP', itime, &
                    npp_daily, npts*npft, horipft_index)
    CALL histwrite (hist_id_stomate, 'GPP', itime, &
                    gpp_daily, npts*npft, horipft_index)
    CALL histwrite (hist_id_stomate, 'IND', itime, &
                    ind, npts*npft, horipft_index)
!    CALL histwrite (hist_id_stomate, 'TOTAL_M', itime, &
!                    tot_live_biomass, npts*npft, horipft_index)
    CALL histwrite (hist_id_stomate, 'LEAF_M', itime, &
                    biomass(:,:,ileaf), npts*npft, horipft_index)
    CALL histwrite (hist_id_stomate, 'SAP_M_AB', itime, &
                    biomass(:,:,isapabove), npts*npft, horipft_index)
    CALL histwrite (hist_id_stomate, 'SAP_M_BE', itime, &
                    biomass(:,:,isapbelow), npts*npft, horipft_index)
    CALL histwrite (hist_id_stomate, 'HEART_M_AB', itime, &
                    biomass(:,:,iheartabove), npts*npft, horipft_index)
    CALL histwrite (hist_id_stomate, 'HEART_M_BE', itime, &
                    biomass(:,:,iheartbelow), npts*npft, horipft_index)
    CALL histwrite (hist_id_stomate, 'ROOT_M', itime, &
                    biomass(:,:,iroot), npts*npft, horipft_index)
    CALL histwrite (hist_id_stomate, 'FRUIT_M', itime, &
                    biomass(:,:,ifruit), npts*npft, horipft_index)
    CALL histwrite (hist_id_stomate, 'RESERVE_M', itime, &
                    biomass(:,:,icarbres), npts*npft, horipft_index)
!    CALL histwrite (hist_id_stomate, 'TOTAL_TURN', itime, &
!                    tot_turnover, npts*npft, horipft_index)
    CALL histwrite (hist_id_stomate, 'LEAF_TURN', itime, &
                    turnover_daily(:,:,ileaf), npts*npft, horipft_index)
    CALL histwrite (hist_id_stomate, 'SAP_AB_TURN', itime, &
                    turnover_daily(:,:,isapabove), npts*npft, horipft_index)
    CALL histwrite (hist_id_stomate, 'ROOT_TURN', itime, &
                    turnover_daily(:,:,iroot), npts*npft, horipft_index)
    CALL histwrite (hist_id_stomate, 'FRUIT_TURN', itime, &
                    turnover_daily(:,:,ifruit), npts*npft, horipft_index)
!    CALL histwrite (hist_id_stomate, 'TOTAL_BM_LITTER', itime, &
!                    tot_bm_to_litter, npts*npft, horipft_index)
    CALL histwrite (hist_id_stomate, 'LEAF_BM_LITTER', itime, &
                    bm_to_litter(:,:,ileaf), npts*npft, horipft_index)
    CALL histwrite (hist_id_stomate, 'SAP_AB_BM_LITTER', itime, &
                    bm_to_litter(:,:,isapabove), npts*npft, horipft_index)
    CALL histwrite (hist_id_stomate, 'SAP_BE_BM_LITTER', itime, &
                    bm_to_litter(:,:,isapbelow), npts*npft, horipft_index)
    CALL histwrite (hist_id_stomate, 'HEART_AB_BM_LITTER', itime, &
                    bm_to_litter(:,:,iheartabove), npts*npft, horipft_index)
    CALL histwrite (hist_id_stomate, 'HEART_BE_BM_LITTER', itime, &
                    bm_to_litter(:,:,iheartbelow), npts*npft, horipft_index)
    CALL histwrite (hist_id_stomate, 'ROOT_BM_LITTER', itime, &
                    bm_to_litter(:,:,iroot), npts*npft, horipft_index)
    CALL histwrite (hist_id_stomate, 'FRUIT_BM_LITTER', itime, &
                    bm_to_litter(:,:,ifruit), npts*npft, horipft_index)
    CALL histwrite (hist_id_stomate, 'RESERVE_BM_LITTER', itime, &
                    bm_to_litter(:,:,icarbres), npts*npft, horipft_index)
    CALL histwrite (hist_id_stomate, 'MAINT_RESP', itime, &
                    resp_maint, npts*npft, horipft_index)
    CALL histwrite (hist_id_stomate, 'GROWTH_RESP', itime, &
                    resp_growth, npts*npft, horipft_index)
    CALL histwrite (hist_id_stomate, 'AGE', itime, &
                    age, npts*npft, horipft_index)
    CALL histwrite (hist_id_stomate, 'HEIGHT', itime, &
                    height, npts*npft, horipft_index)
    CALL histwrite (hist_id_stomate, 'MOISTRESS', itime, &
                    moiavail_week, npts*npft, horipft_index)
    CALL histwrite (hist_id_stomate, 'VCMAX', itime, &
                    vcmax, npts*npft, horipft_index)
   CALL histwrite (hist_id_stomate, 'TURNOVER_TIME', itime, &
                    turnover_time, npts*npft, horipft_index)


    IF (bavard.GE.4) WRITE(numout,*) 'Leaving stomate_lpj'

  END SUBROUTINE StomateLpj

END MODULE stomate_lpj
